@@ -4,13 +4,15 @@ package zsh
 
 import (
 	"fmt"
-	"github.com/jfrog/jfrog-cli-core/utils/coreutils"
+	"github.com/jfrog/jfrog-cli-core/v2/utils/coreutils"
 	"github.com/jfrog/jfrog-client-go/utils/log"
 	"os"
 	"path/filepath"
 )
 
-const ZshAutocomplete = `_jfrog() {
+const ZshAutocomplete = `#compdef _jf jf _jfrog jfrog
+
+_jfrog() {
 	local -a opts
 	opts=("${(@f)$(_CLI_ZSH_AUTOCOMPLETE_HACK=1 ${words[@]:0:#words[@]-1} --generate-bash-completion)}")
 	_describe 'values' opts
@@ -19,9 +21,14 @@ const ZshAutocomplete = `_jfrog() {
 	fi
 }
 
-compdef _jfrog jfrog`
+compdef _jfrog jfrog
+compdef _jfrog jf`
 
-func WriteZshCompletionScript() {
+func WriteZshCompletionScript(install bool) {
+	if !install {
+		fmt.Print(ZshAutocomplete)
+		return
+	}
 	homeDir, err := coreutils.GetJfrogHomeDir()
 	if err != nil {
 		log.Error(err)
