@@ -1,6 +1,7 @@
 package commands
 
 import (
+	"errors"
 	"net/http"
 	"os"
 	"path/filepath"
@@ -169,13 +170,11 @@ func downloadPlugin(pluginsDir, pluginName, downloadUrl string, httpDetails http
 		return
 	}
 	if progressMgr != nil {
+		progressMgr.SetHeadlineMsg("Downloading")
 		progressMgr.InitProgressReaders()
 		progressMgr.IncGeneralProgressTotalBy(1)
 		defer func() {
-			e := progressMgr.Quit()
-			if err == nil {
-				err = e
-			}
+			err = errors.Join(err, progressMgr.Quit())
 		}()
 	}
 
@@ -270,6 +269,6 @@ func downloadFromArtifactory(downloadDetails *httpclient.DownloadFileDetails, ht
 	if err != nil {
 		return
 	}
-	log.Info("Downloading: " + downloadDetails.FileName)
+	log.Info("Downloading:", downloadDetails.FileName)
 	return client.DownloadFileWithProgress(downloadDetails, "", httpDetails, false, false, progressMgr)
 }
