@@ -1,11 +1,12 @@
 package tests
 
 import (
+	"path/filepath"
+
 	"github.com/jfrog/jfrog-cli-core/v2/artifactory/utils"
 	"github.com/jfrog/jfrog-client-go/artifactory/services"
 	servicesUtils "github.com/jfrog/jfrog-client-go/artifactory/services/utils"
 	clientUtils "github.com/jfrog/jfrog-client-go/utils"
-	"path/filepath"
 )
 
 const (
@@ -13,6 +14,7 @@ const (
 	ArchiveEntriesDownload                                = "archive_entries_download_spec.json"
 	ArchiveEntriesUpload                                  = "archive_entries_upload_spec.json"
 	ArtifactoryEndpoint                                   = "artifactory/"
+	LifecycleEndpoint                                     = "lifecycle/"
 	BuildAddDepsDoubleRemoteSpec                          = "build_add_deps_double_remote_spec.json"
 	BuildAddDepsDoubleSpec                                = "build_add_deps_double_spec.json"
 	BuildAddDepsRemoteSpec                                = "build_add_deps_simple_remote_spec.json"
@@ -93,6 +95,7 @@ const (
 	PipenvVirtualRepositoryConfig                         = "pipenv_virtual_repository_config.json"
 	ProdRepo1RepositoryConfig                             = "prod_repo1_repository_config.json"
 	ProdRepo2RepositoryConfig                             = "prod_repo2_repository_config.json"
+	PypiLocalRepositoryConfig                             = "pypi_local_repository_config.json"
 	PypiRemoteRepositoryConfig                            = "pypi_remote_repository_config.json"
 	PypiVirtualRepositoryConfig                           = "pypi_virtual_repository_config.json"
 	ReplicationTempCreate                                 = "replication_push_create.json"
@@ -131,7 +134,6 @@ const (
 	UploadDevSpec                                         = "upload_dev_spec.json"
 	UploadDevSpecA                                        = "upload_dev_spec_a.json"
 	UploadDevSpecB                                        = "upload_dev_spec_b.json"
-	UploadDevSpecC                                        = "upload_dev_spec_c.json"
 	UploadEmptyDirs                                       = "upload_empty_dir_spec.json"
 	UploadExcludeIncludeDir                               = "upload_exclude_include_dir.json"
 	UploadExcludeIncludeDirAntPattern                     = "upload_exclude_include_dir_ant_pattern.json"
@@ -162,38 +164,41 @@ const (
 	WinSimpleUploadSpec                                   = "win_simple_upload_spec.json"
 	XrayEndpoint                                          = "xray/"
 	YarnRemoteRepositoryConfig                            = "yarn_remote_repository_config.json"
+	ReleaseLifecycleImportDependencySpec                  = "import_bundle_repo_dependency.json"
 )
 
 var (
 	// Repositories
-	DistRepo1              = "cli-dist1"
-	DistRepo2              = "cli-dist2"
-	GoRepo                 = "cli-go"
-	GoRemoteRepo           = "cli-go-remote"
-	GoVirtualRepo          = "cli-go-virtual"
-	TerraformRepo          = "cli-terraform"
-	GradleRepo             = "cli-gradle"
-	MvnRemoteRepo          = "cli-mvn-remote"
-	GradleRemoteRepo       = "cli-gradle-remote"
-	MvnRepo1               = "cli-mvn1"
-	MvnRepo2               = "cli-mvn2"
-	NpmRepo                = "cli-npm"
-	NpmRemoteRepo          = "cli-npm-remote"
-	NugetRemoteRepo        = "cli-nuget-remote"
-	YarnRemoteRepo         = "cli-yarn-remote"
-	PypiRemoteRepo         = "cli-pypi-remote"
-	PypiVirtualRepo        = "cli-pypi-virtual"
-	PipenvRemoteRepo       = "cli-pipenv-pypi-remote"
-	PipenvVirtualRepo      = "cli-pipenv-pypi-virtual"
-	DockerLocalRepo        = "cli-docker-local"
-	DockerLocalPromoteRepo = "cli-docker-local-promote"
-	DockerRemoteRepo       = "cli-docker-remote"
-	DockerVirtualRepo      = "cli-docker-virtual"
-	RtDebianRepo           = "cli-debian"
-	RtLfsRepo              = "cli-lfs"
-	RtRepo1                = "cli-rt1"
-	RtRepo2                = "cli-rt2"
-	RtVirtualRepo          = "cli-rt-virtual"
+	DistRepo1                      = "cli-dist1"
+	DistRepo2                      = "cli-dist2"
+	GoRepo                         = "cli-go"
+	GoRemoteRepo                   = "cli-go-remote"
+	GoVirtualRepo                  = "cli-go-virtual"
+	TerraformRepo                  = "cli-terraform"
+	GradleRepo                     = "cli-gradle"
+	MvnRemoteRepo                  = "cli-mvn-remote"
+	GradleRemoteRepo               = "cli-gradle-remote"
+	MvnRepo1                       = "cli-mvn1"
+	MvnRepo2                       = "cli-mvn2"
+	NpmRepo                        = "cli-npm"
+	NpmRemoteRepo                  = "cli-npm-remote"
+	NugetRemoteRepo                = "cli-nuget-remote"
+	YarnRemoteRepo                 = "cli-yarn-remote"
+	PypiLocalRepo                  = "cli-pypi-local"
+	PypiRemoteRepo                 = "cli-pypi-remote"
+	PypiVirtualRepo                = "cli-pypi-virtual"
+	PipenvRemoteRepo               = "cli-pipenv-pypi-remote"
+	PipenvVirtualRepo              = "cli-pipenv-pypi-virtual"
+	DockerLocalRepo                = "cli-docker-local"
+	DockerLocalPromoteRepo         = "cli-docker-local-promote"
+	DockerRemoteRepo               = "cli-docker-remote"
+	DockerVirtualRepo              = "cli-docker-virtual"
+	RtDebianRepo                   = "cli-debian"
+	ReleaseLifecycleDependencyRepo = "npm-prod"
+	RtLfsRepo                      = "cli-lfs"
+	RtRepo1                        = "cli-rt1"
+	RtRepo2                        = "cli-rt2"
+	RtVirtualRepo                  = "cli-rt-virtual"
 	// Repositories that are assigned to an environment.
 	RtDevRepo   = "cli-rt-dev"
 	RtProdRepo1 = "cli-rt-prod1"
@@ -1793,12 +1798,13 @@ func GetGradleDeployedArtifacts() []string {
 }
 
 func GetNpmDeployedScopedArtifacts(isNpm7 bool) []string {
-	path := NpmRepo + "/@jscope/jfrog-cli-tests/-/"
+	path := NpmRepo + "/@jscope/jfrog-cli-tests/-/@jscope/"
 	path += GetNpmArtifactName(isNpm7, true)
 	return []string{
 		path,
 	}
 }
+
 func GetNpmDeployedArtifacts(isNpm7 bool) []string {
 	path := NpmRepo + "/jfrog-cli-tests/-/"
 	path += GetNpmArtifactName(isNpm7, false)
@@ -2103,9 +2109,7 @@ func GetExpectedBackwardCompatibleLifecycleArtifacts() []string {
 		RtDevRepo + "/b1.in",
 		RtDevRepo + "/b2.in",
 		RtDevRepo + "/b3.in",
-		RtDevRepo + "/c1.in",
-		RtDevRepo + "/c2.in",
-		RtDevRepo + "/c3.in",
+		RtDevRepo + "/dep-file",
 	}
 }
 
@@ -2132,9 +2136,7 @@ func GetExpectedLifecycleArtifacts() []string {
 		RtProdRepo1 + "/b1.in",
 		RtProdRepo1 + "/b2.in",
 		RtProdRepo1 + "/b3.in",
-		RtProdRepo1 + "/c1.in",
-		RtProdRepo1 + "/c2.in",
-		RtProdRepo1 + "/c3.in",
+		RtProdRepo1 + "/dep-file",
 	}
 }
 
